@@ -9,22 +9,16 @@ val json_error : string -> 'a
 (** @raise Json_error *)
 
 type lexer_state = {
-  buf : Buffer.t;
-    (** Buffer used to accumulate substrings *)
-
-  mutable lnum : int;
-    (** Current line number (counting from 1) *)
-
+  buf : Buffer.t;  (** Buffer used to accumulate substrings *)
+  mutable lnum : int;  (** Current line number (counting from 1) *)
   mutable bol : int;
-    (** Absolute position of the first character of the current line
+      (** Absolute position of the first character of the current line
         (counting from 0) *)
-
   mutable fname : string option;
-    (** Name referencing the input file in error messages *)
+      (** Name referencing the input file in error messages *)
 }
 
-module Lexer_state :
-sig
+module Lexer_state : sig
   type t = lexer_state = {
     buf : Buffer.t;
     mutable lnum : int;
@@ -34,19 +28,14 @@ sig
 end
 
 val init_lexer :
-  ?buf: Buffer.t ->
-  ?fname: string ->
-  ?lnum: int ->
-  unit -> lexer_state
-  (** Create a fresh lexer_state record. *)
-
+  ?buf:Buffer.t -> ?fname:string -> ?lnum:int -> unit -> lexer_state
+(** Create a fresh lexer_state record. *)
 
 (**/**)
 (* begin undocumented section *)
 
 exception End_of_array
 exception End_of_object
-exception End_of_tuple
 exception End_of_input
 
 (* end undocumented section *)
