@@ -1,20 +1,17 @@
 (**
-   This module supports a specific syntax for variants and tuples
-   in addition to the standard JSON nodes.
+   This module supports a slight superset of the standard JSON nodes.
    Arbitrary integers are supported and represented as a decimal string 
    using [`Intlit] when they cannot be represented using OCaml's int type
    (31 or 63 bits depending on the platform).
 
-   This module is recommended for intensive use 
-   or OCaml-friendly use of JSON.
+   This module is recommended for intensive use or OCaml-friendly use of
+   JSON.
 *)
 
 #define INT
 #define INTLIT
 #define FLOAT
 #define STRING
-#define TUPLE
-#define VARIANT
 
 #include "type.ml"
 
@@ -37,5 +34,3 @@ end
 #undef INTLIT
 #undef FLOAT
 #undef STRING
-#undef TUPLE
-#undef VARIANT
