@@ -4,8 +4,6 @@
 #define FLOATLIT
 #define STRING
 #define STRINGLIT
-#define TUPLE
-#define VARIANT
 
 #include "type.ml"
 
@@ -21,5 +19,3 @@
 #undef FLOATLIT
 #undef STRING
 #undef STRINGLIT
-#undef TUPLE
-#undef VARIANT
