@@ -14,7 +14,6 @@ val to_string :
       @param suf appended to the output as a suffix,
       defaults to empty string.
       @param std use only standard JSON syntax,
-      i.e. convert tuples and variants into standard JSON (if applicable),
       refuse to print NaN and infinities,
       require the root node to be either an object or an array.
       Default is [false].
@@ -143,14 +142,6 @@ val write_stringlit : Buffer.t -> string -> unit
 
 val write_assoc : Buffer.t -> (string * t) list -> unit
 val write_list : Buffer.t -> t list -> unit
-#ifdef TUPLE
-val write_tuple : Buffer.t -> t list -> unit
-val write_std_tuple : Buffer.t -> t list -> unit
-#endif
-#ifdef VARIANT
-val write_variant : Buffer.t -> string -> t option -> unit
-val write_std_variant : Buffer.t -> string -> t option -> unit
-#endif
 
 val write_json : Buffer.t -> t -> unit
 val write_std_json : Buffer.t -> t -> unit
