@@ -83,7 +83,7 @@ let unquoted_from_string () =
     __LOC__ Fixtures.unquoted_value
     (Yojson.Safe.from_string Fixtures.unquoted_json)
 
-let map_ident_and_string () =
+let map_ident () =
   let lexbuf = Lexing.from_string {|{foo:"hello"}|} in
   let lexer_state = Yojson.init_lexer () in
 
@@ -98,17 +98,13 @@ let map_ident_and_string () =
   let skip_over f = f lexer_state lexbuf in
   let map_f mapper f = mapper lexer_state f lexbuf in
   let map_ident = map_f Yojson.Safe.map_ident in
-  let map_string = map_f Yojson.Safe.map_string in
 
   skip_over Yojson.Safe.read_lcurl;
   map_ident (ident_expected "foo");
   skip_over Yojson.Safe.read_colon;
 
-  let variant = skip_over Yojson.Safe.start_any_variant in
-  Alcotest.(check Testable.variant_kind)
-    "String starts with double quote" `Double_quote variant;
-
-  map_string (ident_expected "hello");
+  let key = skip_over Yojson.Safe.read_string in
+  Alcotest.(check string) "String is as expected" "hello" key;
 
   Alcotest.check_raises "Reading } raises End_of_object" Yojson.End_of_object
     (fun () -> Yojson.Safe.read_object_end lexbuf)
@@ -137,5 +133,5 @@ let single_json =
     ("from_string_fail_escaped_char", `Quick, from_string_fail_escaped_char);
     ("from_file", `Quick, from_file);
     ("unquoted_from_string", `Quick, unquoted_from_string);
-    ("map_ident/map_string", `Quick, map_ident_and_string);
+    ("map_ident", `Quick, map_ident);
   ]
